@@ -342,7 +342,9 @@ function import_category($userfile) {
 			$pid = $arr[0];
 
 			/* Stripping dangerous characters from fields */
-			$fldarr[1] = ereg_replace("\'","",$fldarr[1]);
+//			$fldarr[1] = ereg_replace("\'","",$fldarr[1]);
+			$fldarr[1] = ereg_replace("\"","\\\"",$fldarr[1]);
+			$fldarr[1] = ereg_replace("'","\'",$fldarr[1]);
 
 //			$fldarr[3] = ereg_replace("\'","",$fldarr[3]);
 			$fldarr[3] = ereg_replace("'","\'",$fldarr[3]);
