@@ -125,6 +125,19 @@ switch (nvl($mode)) {
 			$frm["product_id"] = $HTTP_POST_VARS["product_id"];
 			$frm["name"] = $HTTP_POST_VARS["name"];
 			$frm["price"] = $HTTP_POST_VARS["price"];
+			if ($SESSION["brand_used"]) {
+				// load up all the brands
+				$qid = db_query("SELECT id, name FROM brands");
+				$frm["brands"] = array();
+				$numr = db_num_rows($qid);
+				$frm["numbrands"] = $numr;
+				for ($i=0; $i<$numr; $i++) {
+					$brand = db_fetch_object($qid, $i);
+					$frm["brand"][$i]["id"] = $brand->id;
+					$frm["brand"][$i]["name"] = $brand->name;
+				}
+				$frm["brand_id"] = $HTTP_POST_VARS["brand_id"];
+			}
 			if ($SESSION["iva_used"]) {
 				// load up all the iva percentuals
 				$qid = db_query("SELECT id, iva FROM iva ORDER BY iva");
@@ -694,7 +707,9 @@ function import_products($HTTP_POST_FILES) {
 
 			/* Stripping dangerous characters from fields */
 			$fldarr[1] = ereg_replace("\'","",$fldarr[1]);
-			$fldarr[2] = ereg_replace("\'","",$fldarr[2]);
+//			$fldarr[2] = ereg_replace("\'","",$fldarr[2]);
+			$fldarr[2] = ereg_replace("'","\'",$fldarr[2]);
+			$fldarr[2] = ereg_replace("\"","\\\"",$fldarr[2]);
 			$fldarr[3] = ereg_replace("\'","",$fldarr[3]);
 			if($SESSION["brand_used"]) {
 				if ($fldarr[3] == "") {
@@ -746,6 +761,7 @@ function import_products($HTTP_POST_FILES) {
 //			$fldarr[10] = ereg_replace("\'","",$fldarr[10]);
 			$fldarr[10] = ereg_replace("'","\'",$fldarr[10]);
 			$fldarr[10] = ereg_replace("\"","\\\"",$fldarr[10]);
+			$fldarr[11] = ereg_replace("'","\'",$fldarr[11]);
 			$fldarr[11] = ereg_replace("\"","\\\"",$fldarr[11]);
 
 			/* ... and let's see if the product already exists ... */
