@@ -197,6 +197,8 @@ switch (nvl($mode)) {
 		break;
 
 	default :
+		$SESSION["goback"]["request_uri"] = $REQUEST_URI;
+		$SESSION["goback"]["query_string"] = $QUERY_STRING;
 		print_user_list();
 		break;
 }
@@ -443,16 +445,21 @@ function import_users($userfile) {
 		$fldarr[3] = ereg_replace("\'","",$fldarr[3]);
 //		$fldarr[4] = ereg_replace("\'","",$fldarr[4]);
 		$fldarr[4] = ereg_replace("'","\'",$fldarr[4]);
+		$fldarr[4] = ereg_replace("\"","\\\"",$fldarr[4]);
 //		$fldarr[5] = ereg_replace("\'","",$fldarr[5]);
 		$fldarr[5] = ereg_replace("'","\'",$fldarr[5]);
+		$fldarr[5] = ereg_replace("\"","\\\"",$fldarr[5]);
 		$fldarr[6] = ereg_replace("\'","",$fldarr[6]);
 //		$fldarr[7] = ereg_replace("\'","",$fldarr[7]);
 		$fldarr[7] = ereg_replace("'","\'",$fldarr[7]);
+		$fldarr[7] = ereg_replace("\"","\\\"",$fldarr[7]);
 		$fldarr[8] = ereg_replace("\'","",$fldarr[8]);
 //		$fldarr[9] = ereg_replace("\'","",$fldarr[9]);
 		$fldarr[9] = ereg_replace("'","\'",$fldarr[9]);
+		$fldarr[9] = ereg_replace("\"","\\\"",$fldarr[9]);
 //		$fldarr[10] = ereg_replace("\'","",$fldarr[10]);
 		$fldarr[10] = ereg_replace("'","\'",$fldarr[10]);
+		$fldarr[10] = ereg_replace("\"","\\\"",$fldarr[10]);
 		$fldarr[11] = ereg_replace("\'","",$fldarr[11]);
 		$fldarr[12] = ereg_replace("\'","",$fldarr[12]);
 		$fldarr[13] = ereg_replace("\'","",$fldarr[13]);
@@ -462,8 +469,10 @@ function import_users($userfile) {
 		$fldarr[17] = ereg_replace("\'","",$fldarr[17]);
 //		$fldarr[18] = ereg_replace("\'","",$fldarr[18]);
 		$fldarr[18] = ereg_replace("'","\'",$fldarr[18]);
+		$fldarr[18] = ereg_replace("\"","\\\"",$fldarr[18]);
 //		$fldarr[19] = ereg_replace("\'","",$fldarr[19]);
 		$fldarr[19] = ereg_replace("'","\'",$fldarr[19]);
+		$fldarr[19] = ereg_replace("\"","\\\"",$fldarr[19]);
 		$fldarr[20] = ereg_replace("\'","",$fldarr[20]);
 		$fldarr[21] = ereg_replace("\'","",$fldarr[21]);
 
