@@ -21,6 +21,7 @@ $Logout = "Logout";
 $Username = "Username";
 $Password = "Password";
 $Password_Confirm = "Password (conferma)";
+$Change_Password = "Modifica Password";
 $Edit = "Modifica";
 $Delete = "Elimina";
 $Remove = "Rimuovi";
@@ -42,6 +43,7 @@ $The_product = "Il prodotto";
 $Add_Product = "Aggiungi prodotto";
 $Delete_Product = "Elimina prodotto";
 $Edit_Product = "Modifica prodotto";
+$Items = "pezzi";
 $Add_Subcategory = "Aggiungi sottocategoria";
 $Add_Brand = "Aggiungi marca";
 $Add_IVA = "Aggiungi IVA";
@@ -58,6 +60,7 @@ $MobilePhone = "Cellulare";
 $Order_Details = "Dettagli dell'ordine";
 $Price = "Prezzo";
 $Weight = "Peso";
+$Total_weight = "Peso totale";
 $Qty = "Q.t&agrave;";
 $Sub_Total = "Sub Totale";
 $Grand_Total = "Totale complessivo";
@@ -67,7 +70,7 @@ $Add_to_Shopping_Cart = "+ Aggiungi al carrello della spesa";
 $Image = "Immagine";
 $Notes = "Annotazioni";
 $Our_Notes = "Nostre Annotazioni";
-$Change_Settings = "Modifica preferenze";
+$Change_Settings = "Modifica Impostazioni";
 $First_Name = "Nome";
 $Last_Name = "Cognome";
 $Fiscal_Code = "Codice Fiscale";
@@ -92,9 +95,6 @@ $Signup_Italy = "Iscrizione (Italia)";
 $Signup_non_Italy = "Iscrizione (Estero)";
 $Enterprises_Signup = "Iscrizione Aziende";
 $Shopping = "Acquisto";
-$Change_Password = "Modifica Password";
-$Items = "Articoli";
-$Total_weight = "Peso totale";
 $Purchase_Now = "Acquista ora";
 $Search_the_Catalog = "Cerca nel catalogo";
 $At_least_a_word = "Almeno una parola";
@@ -141,7 +141,6 @@ $Description = "Descrizione";
 $Extended_Description = "Descrizione estesa";
 $Discount = "Sconto";
 $Starting_from = "a partire da";
-$Items = "pezzi";
 $C_Add_Category = "[+C] Aggiungi categoria";
 $C_Add_Brand = "[+C] Aggiungi marca";
 $C_Add_IVA = "[+C] Aggiungi percentuale IVA";
@@ -168,15 +167,12 @@ $Edit_this_IVA = "Modifica questa percentuale di IVA";
 $admin_footer_message = $CFG->myname . " \"<i>Commercio elettronico - Electronic Store</i>\"";
 $Brand_reset_for_products = "La marca &egrave; stata azzerata per i prodotti di tale marca";
 $IVA_reset_for_products = "La percentuale di IVA &egrave; stata azzerata per i prodotti con tale IVA";
-$Add_Product = "Aggiungi prodotto";
 $Users = "Utenti";
-$Credit_Card = "Carta di Credito";
 $Edit_this_order = "Modifica questo ordine";
 $Delete_this_order = "Cancella questo ordine";
 $Order = "Ordine";
 $Orders = "Ordini";
 $The_order = "L'ordine";
-$has_been_deleted_male_singular = "&egrave; stato eliminato";
 $Sent = "Spedito";
 $Paid = "Pagato";
 $Ordered = "Ordinato";
@@ -241,7 +237,6 @@ $Your_shopping_cart_is_empty = "Il tuo carrello &egrave; vuoto, <a href=\"".$CFG
 $Billing_Details = "Dettagli dell'acquisto";
 $Date = "Data";
 $Bill_to = "Venduto a";
-$Total_weight = "Peso totale";
 $Contact = "Recapito";
 $Comments_and_Special_Instructions = "Commenti / Istruzioni speciali";
 $Step_1_Enter_Billing_Information = "Passo 1. Inserisci le informazioni per l'acquisto";
@@ -261,8 +256,6 @@ $Empty_the_Cart = "Svuota il carrello";
 // users scripts
 ////////////////////////////////////////////////////////////
 
-$Change_Password = "Modifica Password";
-$Change_Settings = "Modifica Impostazioni";
 $Password_Change_Successful = "Modifica della password effettuata con successo";
 $Settings_Change_Successful = "Impostazioni modificate con successo";
 $Signup = "Iscrizione";
@@ -364,15 +357,15 @@ $zip_code_length_is_wrong = "Il CAP deve contenere esattamente " . $SESSION["zip
 $empty_phone = "Non &egrave; stato specificato il numero di telefono";
 $phone_too_long = "Numero di telefono troppo lungo: ".$SESSION["phone_length"]." caratteri max";
 $phone_too_short = "Numero di telefono troppo corto: ".$SESSION["phone_length_min"]." caratteri min";
-$not_valid_phone = "Numero di telefono non valido";
+$not_valid_phone = "Numero di telefono non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
 
 $fax_too_long = "Numero di fax troppo lungo: ".$SESSION["fax_length"]." caratteri max";
 $fax_too_short = "Numero di fax troppo corto: ".$SESSION["fax_length_min"]." caratteri min";
-$not_valid_fax = "Numero di fax non valido";
+$not_valid_fax = "Numero di fax non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
 
 $mobilephone_too_long = "Numero di cellulare troppo lungo: ".$SESSION["mobilephone_length"]." caratteri max";
 $mobilephone_too_short = "Numero di cellulare troppo corto: ".$SESSION["mobilephone_length_min"]." caratteri min";
-$not_valid_mobilephone = "Numero di cellulare non valido";
+$not_valid_mobilephone = "Numero di cellulare non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
 
 $empty_email = "Non &egrave; stato specificato l'indirizzo e-mail";
 $email_too_long = "Indirizzo e-mail troppo lungo: ".$SESSION["email_length"]." caratteri max";
