@@ -21,6 +21,7 @@ $Logout = "Logout";
 $Username = "Username";
 $Password = "Password";
 $Password_Confirm = "Password (confirm)";
+$Change_Password = "Change Password";
 $Edit = "Edit";
 $Delete = "Delete";
 $Remove = "Remove";
@@ -42,6 +43,7 @@ $The_product = "The product";
 $Add_Product = "Add Product";
 $Delete_Product = "Delete Product";
 $Edit_Product = "Edit Product";
+$Items = "items";
 $Add_Subcategory = "Add Subcategory";
 $Add_Brand = "Add Brand";
 $Add_IVA = "Add IVA";
@@ -58,6 +60,7 @@ $MobilePhone = "Mobile Phone";
 $Order_Details = "Order Details";
 $Price = "Price";
 $Weight = "Weight";
+$Total_weight = "Total weight";
 $Qty = "Qty";
 $Sub_Total = "Sub Total";
 $Grand_Total = "Grand Total";
@@ -92,9 +95,6 @@ $Signup_Italy = "Signup (Italy)";
 $Signup_non_Italy = "Signup (outside of Italy)";
 $Enterprises_Signup = "Enterprises Signup";
 $Shopping = "Shopping";
-$Change_Password = "Change Password";
-$Items = "Items";
-$Total_weight = "Total Weight";
 $Purchase_Now = "Purchase Now";
 $Search_the_Catalog = "Search the Catalog";
 $At_least_a_word = "At least a word";
@@ -141,7 +141,6 @@ $Description = "Description";
 $Extended_Description = "Extended Description";
 $Discount = "Discount";
 $Starting_from = "starting from";
-$Items = "items";
 $C_Add_Category = "[+C] Add Category";
 $C_Add_Brand = "[+C] Add Brand";
 $C_Add_IVA = "[+C] Add IVA percentual";
@@ -168,15 +167,12 @@ $Edit_this_IVA = "Edit this IVA percentual";
 $admin_footer_message = $CFG->myname . " \"<i>Electronic Store - Commercio elettronico</i>\"";
 $Brand_reset_for_products = "The Brand has been reset for all products of that brand";
 $IVA_reset_for_products = "The IVA percentual has been reset for all products with that IVA percentual";
-$Add_Product = "Add Product";
 $Users = "Users";
-$Credit_Card = "Credit Card";
 $Edit_this_order = "Edit this order";
 $Delete_this_order = "Delete this order";
 $Order = "Order";
 $Orders = "Orders";
 $The_order = "The order";
-$has_been_deleted_male_singular = "has been deleted";
 $Sent = "Sent";
 $Paid = "Paid";
 $Ordered = "Ordered";
@@ -241,7 +237,6 @@ $Your_shopping_cart_is_empty = "Your shopping cart is empty, <a href=\"".$CFG->w
 $Billing_Details = "Billing Details";
 $Date = "Date";
 $Bill_to = "Bill to";
-$Total_weight = "Total weight";
 $Contact = "Contact";
 $Comments_and_Special_Instructions = "Comments / Special Instructions";
 $Step_1_Enter_Billing_Information = "Step 1. Enter Billing Information";
@@ -261,8 +256,6 @@ $Empty_the_Cart = "Empty the Cart";
 // users scripts
 ////////////////////////////////////////////////////////////
 
-$Change_Password = "Change Password";
-$Change_Settings = "Change Settings";
 $Password_Change_Successful = "Password Change Successful";
 $Settings_Change_Successful = "Settings Change Successful";
 $Signup = "Signup";
@@ -361,15 +354,15 @@ $zip_code_length_is_wrong = "The Zip Code must consist of exactly " . $SESSION["
 $empty_phone = "Please specify the phone number";
 $phone_too_long = "Phone number too much long: ".$SESSION["phone_length"]." characters max";
 $phone_too_short = "Phone number too much short: ".$SESSION["phone_length_min"]." characters min";
-$not_valid_phone = "Phone number not valid";
+$not_valid_phone = "Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";
 
 $fax_too_long = "Fax number too much long: ".$SESSION["fax_length"]." characters max";
 $fax_too_short = "Fax number too much short: ".$SESSION["fax_length_min"]." characters min";
-$not_valid_fax = "Fax number not valid";
+$not_valid_fax = "Fax number not valid; only cyphers, spaces, +-()/ are allowed characters";
 
 $mobilephone_too_long = "Mobile Phone number too much long: ".$SESSION["mobilephone_length"]." characters max";
 $mobilephone_too_short = "Mobile Phone number too much short: ".$SESSION["mobilephone_length_min"]." characters min";
-$not_valid_mobilephone = "Mobile Phone number not valid";
+$not_valid_mobilephone = "Mobile Phone number not valid; only cyphers, spaces, +-()/ are allowed characters";
 
 $empty_email = "Please specify the E-mail address";
 $email_too_long = "E-mail address too much long: ".$SESSION["email_length"]." characters max";
